import { ResourceProps } from 'aws-cdk-lib';
import * as cloudfront from 'aws-cdk-lib/aws-cloudfront';
import * as lambda from 'aws-cdk-lib/aws-lambda';
import { Construct } from 'constructs';
/**
 * Properties for the CloudfrontGeoLocator construct.
 */
export interface CloudfrontGeoLocatorProps extends ResourceProps {
    /**
     * A unique name to identify the s3 bucket.
     *
     * @default - cloudfront-geo-locator-origin
     */
    readonly s3BucketName?: string;
    /**
     * A unique name to identify the lambda function.
     *
     * @default - cloudfront-geo-locator
     */
    readonly lambdaFunctionName?: string;
    /**
     * A unique name to identify the cloudfront cache policy.
     *
     * @default - CloudfrontGeoLocatorCachePolicy
     */
    readonly cloudfrontCachePolicyName?: string;
    /**
     * A unique name to identify the cloudfront origin request policy.
     *
     * @default - CloudfrontGeoLocatorOriginRequestPolicy
     */
    readonly cloudfrontOriginRequestPolicyName?: string;
    /**
     * The price class for the CloudFront distribution.
     *
     * @default - PRICE_CLASS_100
     */
    readonly cloudfrontPriceClass?: cloudfront.PriceClass;
    /**
     * The domain name for the CloudFront distribution.
     *
     * @default - undefined
     */
    readonly customDomainName?: string;
    /**
     * The ARN of the certificate.
     *
     * @default - undefined
     */
    readonly customDomainCertificateArn?: string;
}
export declare class CloudfrontGeoLocator extends Construct {
    /**
     * The ARN of the S3 bucket.
     */
    readonly s3BucketArn: string;
    /**
     * The ARN of the Lambda function.
     */
    readonly lambdaFunctionArn: string;
    /**
     * The current version of the Lambda function.
     */
    readonly lambdaFunctionVersion: lambda.Version;
    /**
     * The ID of the CloudFront distribution.
     */
    readonly distributionId: string;
    /**
     * The domain name of the CloudFront distribution.
     */
    readonly distributionDomainName: string;
    /**
     * The ID of the CloudFront cache policy.
     */
    readonly cloudfrontCachePolicyId: string;
    /**
     * The ID of the CloudFront origin request policy.
     */
    readonly cloudfrontOriginRequestPolicyId: string;
    constructor(scope: Construct, id: string, props?: CloudfrontGeoLocatorProps);
    private _createBucket;
    private _createFunction;
    private _createDistributionCachePolicy;
    private _createDistributionOriginRequestPolicy;
    private _createOriginAccessIdentity;
    private _createDistribution;
    private _modifyImagesBucketPolicy;
}
